<?php
/**
 * @package    TGM-Plugin-Activation
 * @subpackage Zefir 2.0
 * @version    2.4.2
 * @author     Thomas Griffin
 * @author     Gary Jones
 * @copyright  Copyright (c) 2011, Thomas Griffin
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       https://github.com/thomasgriffin/TGM-Plugin-Activation
 */

add_action('tgmpa_register', 'bird_register_required_plugins');

/**
 * Register the required plugins for this theme.
 *
 * The variable passed to tgmpa_register_plugins() should be an array of plugin
 * arrays.
 *
 * This function is hooked into tgmpa_init, which is fired within the
 * TGM_Plugin_Activation class constructor.
 */
function bird_register_required_plugins() {

  /**
   * Array of plugin arrays. Required keys are name and slug.
   * If the source is NOT from the .org repo, then source is also required.
   */
  $plugins = array(

    // meta-box plugin - required
    array(
      'name'               => 'Meta Box', // The plugin name.
      'slug'               => 'meta-box', // The plugin slug (typically the folder name).
      'required'           => true, // If false, the plugin is only 'recommended' instead of required.
      'force_activation'   => true, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
      'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
    ),

    // Zefir Shortcodes - recommended
    array(
      'name'     				    => 'Zefir Shortcodes', // The plugin name
      'slug'     				    => 'zefir-shortcodes', // The plugin slug (typically the folder name)
      'source'   				    => get_stylesheet_directory().'/assets/plugins/zefir-shortcodes.zip', // The plugin source
      'required' 				    => false, // If false, the plugin is only 'recommended' instead of required
      'version' 				    => '', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
      'force_activation'    => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
      'force_deactivation' 	=> false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
      'external_url' 			  => '', // If set, overrides default API URL and points to an external URL
    ),

    // Ajax Thumbnail Rebuild - recommended
    array(
      'name'     				    => 'Ajax Thumbnail Rebuild', // The plugin name
      'slug'     				    => 'ajax-thumbnail-rebuild', // The plugin slug (typically the folder name)
      'source'   				    => get_stylesheet_directory().'/assets/plugins/ajax-thumbnail-rebuild.1.12.zip', // The plugin source
      'required' 				    => false, // If false, the plugin is only 'recommended' instead of required
      'version' 				    => '', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
      'force_activation'    => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
      'force_deactivation' 	=> false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
      'external_url' 			  => '', // If set, overrides default API URL and points to an external URL
    ),

  );

  /**
   * Array of configuration settings. Amend each line as needed.
   * If you want the default strings to be available under your own theme domain,
   * leave the strings uncommented.
   * Some of the strings are added into a sprintf, so see the comments at the
   * end of each line for what each argument will be.
   */
  $config = array(
    'id'           => 'tgmpa',                 // Unique ID for hashing notices for multiple instances of TGMPA.
    'default_path' => '',                      // Default absolute path to pre-packaged plugins.
    'menu'         => 'tgmpa-install-plugins', // Menu slug.
    'parent_slug'  => 'themes.php',            // Parent menu slug.
    'capability'   => 'edit_theme_options',    // Capability needed to view plugin install page, should be a capability associated with the parent menu used.
    'has_notices'  => true,                    // Show admin notices or not.
    'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
    'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
    'is_automatic' => true,                   // Automatically activate plugins after installation or not.
    'message'      => '',                      // Message to output right before the plugins table.
    'strings'      => array(
      'page_title'                      => __( 'Install Required Plugins', 'birdwp-theme' ),
      'menu_title'                      => __( 'Install Plugins', 'birdwp-theme' ),
      'installing'                      => __( 'Installing Plugin: %s', 'birdwp-theme' ), // %s = plugin name.
      'oops'                            => __( 'Something went wrong with the plugin API.', 'birdwp-theme' ),
      'notice_can_install_required'     => _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.', 'birdwp-theme' ), // %1$s = plugin name(s).
      'notice_can_install_recommended'  => _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.', 'birdwp-theme' ), // %1$s = plugin name(s).
      'notice_cannot_install'           => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.', 'birdwp-theme' ), // %1$s = plugin name(s).
      'notice_can_activate_required'    => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.', 'birdwp-theme' ), // %1$s = plugin name(s).
      'notice_can_activate_recommended' => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.', 'birdwp-theme' ), // %1$s = plugin name(s).
      'notice_cannot_activate'          => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.', 'birdwp-theme' ), // %1$s = plugin name(s).
      'notice_ask_to_update'            => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.', 'birdwp-theme' ), // %1$s = plugin name(s).
      'notice_cannot_update'            => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.', 'birdwp-theme' ), // %1$s = plugin name(s).
      'install_link'                    => _n_noop( 'Begin installing plugin', 'Begin installing plugins', 'birdwp-theme' ),
      'activate_link'                   => _n_noop( 'Begin activating plugin', 'Begin activating plugins', 'birdwp-theme' ),
      'return'                          => __( 'Return to Required Plugins Installer', 'birdwp-theme' ),
      'plugin_activated'                => __( 'Plugin activated successfully.', 'birdwp-theme' ),
      'complete'                        => __( 'All plugins installed and activated successfully. %s', 'birdwp-theme' ), // %s = dashboard link.
      'nag_type'                        => 'updated' // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
    )
  );

  tgmpa( $plugins, $config );

}
