<?php
/**
 * The template for displaying Comments
 *
 * @package WordPress
 * @subpackage Zefir
 * @since Zefir 1.0
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() )
  return;
?>

<div id="comments" class="comments-area">

  <?php // You can start editing here -- including this comment! ?>

  <?php if ( have_comments() ) : ?>
    <h2 class="comments-title">
	  <?php
	  printf( _n( 'One thought on &ldquo;%2$s&rdquo;', '%1$s thoughts on &ldquo;%2$s&rdquo;', get_comments_number(), 'birdwp-theme' ),
	    number_format_i18n( get_comments_number() ), '<span>' . get_the_title() . '</span>' );
      ?>
    </h2>

    <ol class="commentlist">
      <?php wp_list_comments( array( 'callback' => 'bird_comment', 'style' => 'ol' ) ); ?>
    </ol><!-- .commentlist -->

	  <?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // are there comments to navigate through ?>
      <nav id="comment-nav-below" class="navigation" role="navigation">
        <h1 class="assistive-text section-heading"><?php esc_html_e( 'Comment navigation', 'birdwp-theme' ); ?></h1>
        <div class="nav-previous"><?php previous_comments_link( __( '&larr; Older Comments', 'birdwp-theme' ) ); ?></div>
        <div class="nav-next"><?php next_comments_link( __( 'Newer Comments &rarr;', 'birdwp-theme' ) ); ?></div>
      </nav>
    <?php endif; // check for comment navigation ?>

	  <?php
    /* If there are no comments and comments are closed, let's leave a note.
     * But we only want the note on posts and pages that had comments in the first place.
     */
    if ( ! comments_open() && get_comments_number() ) : ?>
      <p class="nocomments"><?php esc_html_e( 'Comments are closed.' , 'birdwp-theme' ); ?></p>
    <?php endif; ?>
  <?php endif; // have_comments() ?>

  <?php
  $comment_args = array(
    'comment_notes_before' => '<p class="comment-notes">' . esc_html__( 'Your email address will not be published. Required fields are marked *', 'birdwp-theme') . '</p>',
    'title_reply' => esc_html__('Leave a Reply', 'birdwp-theme'),
    'title_reply_to' => esc_html__('Leave a Reply to %s', 'birdwp-theme'),
    'cancel_reply_link' => esc_html__('Cancel reply', 'birdwp-theme'),
    'label_submit' => esc_html__('Post Comment', 'birdwp-theme')
  );
  comment_form($comment_args);
  ?>

</div><!-- #comments .comments-area -->